Documentation
¶
Index ¶
- type Logger
- func (_m *Logger) Debug(msg string, fields ...edatlog.Field)
- func (_m *Logger) Error(msg string, fields ...edatlog.Field)
- func (_m *Logger) Info(msg string, fields ...edatlog.Field)
- func (_m *Logger) Sub(fields ...edatlog.Field) edatlog.Logger
- func (_m *Logger) Trace(msg string, fields ...edatlog.Field)
- func (_m *Logger) Warn(msg string, fields ...edatlog.Field)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Logger ¶
Logger is an autogenerated mock type for the Logger type
func NewLogger ¶
NewLogger creates a new instance of Logger. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
Click to show internal directories.
Click to hide internal directories.